@@ -22,7 +22,7 @@ private slots:
 
     void on_pushButton_2_clicked();
 
-   // void on_horizontalSlider_valueChanged(int value);
+    void on_horizontalSlider_valueChanged(int value);
 
 private:
     Ui::SettingsDlg *ui;
